.. -*- mode: rst -*-

===========================
django-extended-attachments
===========================

django-extended-attachments is a file storage application
with following features:

- Automatic thumbnail generation
- Antivirus check
- SHA1 checksums
- MediaWiki file path style
- File description
- Access permission check callbacks

This application based on `django-attachments`
and `django-filetransfers`.

Requires
~~~~~~~~

- django-extensions
- django >= 1.2
- python >= 2.6
